@@ -18,6 +18,7 @@ from ansiblelint.constants import LINE_NUMBER_KEY
 from ansiblelint.errors import RuleMatchTransformMeta
 from ansiblelint.file_utils import Lintable
 from ansiblelint.rules import AnsibleLintRule, TransformMixin
+from ansiblelint.runner import get_matches
 from ansiblelint.skip_utils import get_rule_skips_from_line
 from ansiblelint.text import has_jinja
 from ansiblelint.utils import parse_yaml_from_file, template
@@ -142,7 +143,7 @@ class JinjaRule(AnsibleLintRule, TransformMixin):
                         )
                         if ignored_re.search(orig_exc_message) or isinstance(
                             orig_exc,
-                            AnsibleParserError,
+                            (AnsibleParserError, TypeError),
                         ):
                             # An unhandled exception occurred while running the lookup plugin 'template'. Error was a <class 'ansible.errors.AnsibleError'>, original message: the template file ... could not be found for the lookup. the template file ... could not be found for the lookup
 
@@ -482,10 +483,7 @@ if "pytest" in sys.modules:
     import pytest
 
     from ansiblelint.rules import RulesCollection  # pylint: disable=ungrouped-imports
-    from ansiblelint.runner import (
-        Runner,
-        _get_matches,
-    )
+    from ansiblelint.runner import Runner
 
     # pylint: disable=ungrouped-imports
     from ansiblelint.transformer import Transformer  # pylint: disable=ungrouped-imports
@@ -840,7 +838,7 @@ if "pytest" in sys.modules:
         config_options.write_list = ["all"]
 
         config_options.lintables = [playbook]
-        runner_result = _get_matches(
+        runner_result = get_matches(
             rules=default_rules_collection,
             options=config_options,
         )
