@@ -14,6 +14,7 @@ from typing import TYPE_CHECKING, Any, Callable, Union, cast
 
 import ruamel.yaml.events
 from ruamel.yaml.comments import CommentedMap, CommentedSeq, Format
+from ruamel.yaml.composer import ComposerError
 from ruamel.yaml.constructor import RoundTripConstructor
 from ruamel.yaml.emitter import Emitter, ScalarAnalysis
 
@@ -27,7 +28,6 @@ from ansiblelint.constants import (
     ANNOTATION_KEYS,
     NESTED_TASK_KEYS,
     PLAYBOOK_TASK_KEYWORDS,
-    SKIPPED_RULES_KEY,
 )
 from ansiblelint.utils import Task
 
@@ -212,7 +212,7 @@ def _nested_items_path(
         msg = f"Expected a dict or a list but got {data_collection!r} of type '{type(data_collection)}'"
         raise TypeError(msg)
     for key, value in convert_data_collection_to_tuples():
-        if key in (SKIPPED_RULES_KEY, "__file__", "__line__", *ignored_keys):
+        if key in (*ANNOTATION_KEYS, *ignored_keys):
             continue
         yield key, value, parent_path
         if isinstance(value, (dict, list)):
@@ -338,7 +338,7 @@ def _get_path_to_task_in_playbook(
     return []
 
 
-def _get_path_to_task_in_tasks_block(  # noqa: C901
+def _get_path_to_task_in_tasks_block(
     lineno: int,  # 1-based
     tasks_block: CommentedSeq,
     last_lineno: int | None = None,  # 1-based
@@ -583,7 +583,7 @@ class FormattedEmitter(Emitter):
         """Select how to quote scalars if needed."""
         style = super().choose_scalar_style()
         if (
-            style == ""  # noqa: PLC1901
+            style == ""
             and self.event.value.startswith("0")
             and len(self.event.value) > 1
         ):
@@ -599,6 +599,17 @@ class FormattedEmitter(Emitter):
             return "'"
         return self.preferred_quote
 
+    def increase_indent(
+        self,
+        flow: bool = False,  # noqa: FBT002
+        sequence: bool | None = None,
+        indentless: bool = False,  # noqa: FBT002
+    ) -> None:
+        super().increase_indent(flow, sequence, indentless)
+        # If our previous node was a sequence and we are still trying to indent, don't
+        if self.indents.last_seq():
+            self.indent = self.column + 1
+
     def write_indicator(
         self,
         indicator: str,  # ruamel.yaml typehint is wrong. This is a string.
@@ -621,6 +632,9 @@ class FormattedEmitter(Emitter):
             and not self._in_empty_flow_map
         ):
             indicator = (" " * spaces_inside) + "}"
+        # Indicator sometimes comes with embedded spaces we need to squish
+        if indicator == "  -" and self.indents.last_seq():
+            indicator = "-"
         super().write_indicator(indicator, need_whitespace, whitespace, indention)
         # if it is the start of a flow mapping, and it's not time
         # to wrap the lines, insert a space.
@@ -696,12 +710,19 @@ class FormattedEmitter(Emitter):
                     ruamel.yaml.events.CollectionEndEvent,
                     ruamel.yaml.events.DocumentEndEvent,
                     ruamel.yaml.events.StreamEndEvent,
+                    ruamel.yaml.events.MappingStartEvent,
                 ),
             )
         ):
             # drop pure whitespace pre comments
             # does not apply to End events since they consume one of the newlines.
             value = ""
+        elif (
+            pre
+            and not value.strip()
+            and isinstance(self.event, ruamel.yaml.events.MappingStartEvent)
+        ):
+            value = self._re_repeat_blank_lines.sub("", value)
         elif pre:
             # preserve content in pre comment with at least one newline,
             # but no extra blank lines.
@@ -853,7 +874,7 @@ class FormattedYAML(YAML):
         # self.Representer.add_representer(
 
     @staticmethod
-    def _defaults_from_yamllint_config() -> dict[str, bool | int | str]:  # noqa: C901
+    def _defaults_from_yamllint_config() -> dict[str, bool | int | str]:
         """Extract FormattedYAML-relevant settings from yamllint config if possible."""
         config = {
             "explicit_start": True,
@@ -929,7 +950,10 @@ class FormattedYAML(YAML):
         # https://sourceforge.net/p/ruamel-yaml/tickets/460/
 
         text, preamble_comment = self._pre_process_yaml(stream)
-        data = self.load(stream=text)
+        try:
+            data = self.load(stream=text)
+        except ComposerError:
+            data = self.load_all(stream=text)
         if preamble_comment is not None and isinstance(
             data,
             (CommentedMap, CommentedSeq),
